pub struct KeyBudget {
pub max_keys: usize,
pub max_total_bytes: usize,
}Expand description
Candidate-key generation budget passed to language backends.
Fields
max_keys: usizeMaximum number of generated search keys to produce for one candidate.
max_total_bytes: usizeMaximum bytes and mapped characters generated by one language backend.